==> nextcloud-27.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/pt_BR.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Link público",
    "Photos" : "Fotos",
    "Your memories under your control" : "Suas memórias sob seu controle",
    "All media" : "Toda mídia",
    "Videos" : "Vídeos",
    "Albums" : "Álbuns",
    "Collaborative albums" : "Álbuns colaborativos",
    "People" : "Pessoas",
    "Folders" : "Pastas",
    "Favorites" : "Favoritos",
    "On this day" : "Nesse dia",
    "Shared with you" : "Compartilhado com você",
    "Tags" : "Etiquetas",
    "Places" : "Lugares",
    "Map" : "Mapa",
    "Photos settings" : "Configurações de fotos",
    "Mark selection as favorite" : "Marcar seleção como favorito",
    "Add selection to favorites" : "Adicionar seleção aos favoritos",
    "Remove selection from favorites" : "Remover seleção dos favoritos",
    "Name of the album" : "Nome do álbum",
    "Location of the album" : "Localização do álbum",
    "Back" : "Voltar",
    "Add collaborators" : "Adicionar colaboradores",
    "Save" : "Salvar",
    "Create album" : "Criar álbum",
    "Add to Album" : "Adicionar ao Álbum",
    "Add selection to album {albumName}" : "Adicionar seleção ao álbum {albumName}",
    "Shared by" : "Compartilhado por",
    "Create a new album." : "Criar um novo álbum.",
    "Create new album" : "Criar novo álbum",
    "New album" : "Novo álbum",
    "_%n item_::_%n photos and videos_" : ["%nitem","%nfotos e vídeos","%nfotos e vídeos"],
    "Add people or groups who can edit your album" : "Adicione pessoas ou grupos que podem editar seu álbum",
    "Search people or groups" : "Pesquisar pessoas ou grupos",
    "No recommendations. Start typing." : "Sem recomendações. Começe a digitar.",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Remova {collaboratorLabel} da lista de colaboradores",
    "Copy the public link" : "Copiar link público",
    "Public link copied!" : "Link público copiado!",
    "Copy public link" : "Copiar link público",
    "Delete the public link" : "Remover link público",
    "Create public link share" : "Criar compartilhamento de link público",
    "Share via public link" : "Compartilhar via link público",
    "Failed to fetch collaborators list." : "Falha ao buscar a lista de colaboradores.",
    "Failed to update album." : "Falha ao atualizar álbum.",
    "This collection does not exist" : "Esta coleção não existe",
    "An error occurred" : "Ocorreu um erro",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%nfoto não identificada","%nfotos não identificadas","%nfotos não identificadas"],
    "Select image {imageName}" : "Selecionar imagem {imageName}",
    "The file is in the favorites" : "Esse arquivo está nos favoritos",
    "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho normal",
    "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
    "Add to {destination}" : "Adicionar a {destionation}",
    "Open the \"{name}\" sub-directory" : "Abrir o subdiretório \"{name}\"",
    "Back to {folder}" : "Voltar para {folder}",
    "Share this folder" : "Compartilhar esta pasta",
    "_{years} year ago_::_{years} years ago_" : ["{anos} ano atrás","{anos} anos atrás","{anos} anos atrás"],
    "Enable squared photos view" : "Ativar exibição de fotos quadradas",
    "Default Photos upload and Albums location" : "Localização padrão de upload para fotos e álbuns",
    "Choose default Photos upload and Albums location" : "Escolha o upload padrão de fotos e o local dos álbuns",
    "Select the default location for your media" : "Selecione o local padrão para sua mídia",
    "Invalid location selected" : "Invalidar localização selecionada",
    "View" : "Exibição",
    "Photos directory" : "Diretório de fotos",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Desmarque todos",
    "Manage collaborators for this album" : "Gerenciar colaboradores para este álbum",
    "Open actions menu" : "Abrir menu de ações",
    "Edit album details" : "Modificar detalhes do álbu",
    "Download all files in album" : "Baixar todos os arquivos do álbum",
    "Delete album" : "Remover álbum",
    "Download selected files" : "Baixar arquivos selecionados",
    "Remove selection from album" : "Remover seleção do álbum",
    "This album does not have any photos or videos yet!" : "Este álbum ainda não possui fotos ou vídeos!",
    "Add photos to this album" : "Adicionar fotos a este álbum",
    "Add photos to {albumName}" : "Add photos to {albumName}",
    "Manage collaborators" : "Gerenciar colaboradores",
    "Save collaborators for this album." : "Salve os colaboradores deste álbum.",
    "Cover photo for album {albumName}" : "Foto da capa do álbum {albumName}",
    "There is no album yet!" : "Ainda não há álbum!",
    "This person could not be found" : "Essa pessoa não pôde ser encontrada",
    "Rename person" : "Renomear pessoa",
    "Merge with different person" : "Unir com outra pessoa",
    "Download selected photos" : "Baixar fotos selecionadas",
    "Favorite" : "Favorito",
    "Remove from favorites" : "Remover dos favoritos",
    "Remove person" : "Remover pessoa",
    "Name of this person" : "Nome desta pessoa",
    "Save." : "Salvar.",
    "Merge person" : "Unir pessoa",
    "Move to different person" : "Ir para uma pessoa diferente",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover fotos para outra pessoa","Mover fotos para outra pessoa","Mover fotos para outra pessoa"],
    "_Remove photo from person_::_Remove photos from person_" : ["Remover fotos desta pessoa","Remover fotos desta pessoa","Remover fotos desta pessoa"],
    "This might take some time depending on the size of your photo library." : "Isso pode levar um tempo a depender do tamanho da sua biblioteca de fotos.",
    "Recognized people will show up here" : "Pessoas reconhecidas aparecerão aqui",
    "This folder does not exist" : "Esta pasta não existe",
    "Loading folders …" : "Carregando pastas…",
    "No photos in here" : "Não há fotos aqui",
    "This place does not have any photos or videos yet!" : "This place does not have any photos or videos yet!",
    "Add photos to this place" : "Adicionar fotos a este espaço",
    "Cover photo for place {placeName}" : "Foto da capa do lespaço {placeName}",
    "There is no place yet!" : "Ainda não há espaço!",
    "Cover photo for shared album {albumName}." : "Foto da capa do álbum compartilhado {albumName}.",
    "Back to tags overview" : "Voltar para a visão geral das etiquetas",
    "No photos with this tag yet" : "Ainda não há fotos com esta etiqueta",
    "No tags yet" : "Ainda não há marcações",
    "Photos with tags will show up here" : "Fotos com marcações serão mostradas aqui",
    "Popular tags" : "Etiquetas populares",
    "Add" : "Adicionar",
    "Add to album" : "Adicionar a álbum",
    "Delete selection" : "Excluir seleção",
    "No photos or videos in here" : "Não há fotos ou vídeos aqui",
    "Unassigned faces" : "Rostos não identificados",
    "_%n photos_::_%n photos_" : ["%nfoto","%nfotos","%nfotos"],
    "Failed to fetch collection." : "Failed to fetch collection.",
    "Failed to fetch collections list." : "Failed to fetch collections list.",
    "Failed to fetch faces list." : "Falha ao buscar lista de rostos.",
    "All your media" : "Todas as suas mídias",
    "Album {title}" : "Álbum {título}",
    "Shared Albums" : "Álbuns Compartilhados",
    "Shared album {title}" : "Álbum compartilhado {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos marcadas",
    "Tagged photo {title}" : "Foto marcada {title}",
    "{title}'s face" : "rosto de {title}",
    "{startDate} to {endDate}" : "{startDate} até {endDate}",
    "Failed to rename {oldName} to {faceName}." : "Falha ao renomear {oldName} para {faceName}.",
    "Failed to delete {faceName}." : "Falha ao remover {faceName}.",
    "Failed to delete {fileId}." : "Falha ao excluir {fileId}.",
    "Failed to delete {fileName}." : "Falha ao excluir {fileName}.",
    "Failed to set favorite state for {fileId}." : "Falha ao definir o estado de favorito para {fileId}.",
    "Failed to set favorite state for {fileName}." : "Falha ao definir o estado de favorito para {fileName}.",
    "Locations" : "Localizações",
    "Go back to the previous view." : "Ir para a visualização anterior.",
    "Go to the add collaborators view." : "Ir para visualização de adicionar colaboradores.",
    "Create the album." : "Criar o álbum.",
    "Back to the new album form." : "Voltar ao formulário de novo álbum.",
    "_Share with %n user_::_Share with %n users_" : ["Compartilhar com %nusuário","Compartilhar com %nusuários","Compartilhar com %nusuários"],
    "Search for collaborators" : "Pesquisar colaboradores",
    "Add {collaboratorLabel} to the collaborators list" : "Adicionar {collaboratorsLabel} à lista de colaboradores",
    "No collaborators available" : "Nenhum colaborador disponível",
    "Failed to fetch album." : "Falha ao buscar álbum.",
    "Add photos to the album" : "Adicionar fotos ao álbum",
    "Failed to fetch albums list." : "Falha ao buscar lista de álbuns.",
    "Shared albums" : "Álbuns compartilhados",
    "Create a new album" : "Criar um novo álbum",
    "Add selection to an album" : "Adicionar seleção a um álbu",
    "Failed to create {albumName}." : "Falha ao criar {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Falha ao renomear {currentAlbumName} para {newAlbumName}."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/pt_BR.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Link público",
    "Photos" : "Fotos",
    "Your memories under your control" : "Suas memórias sob seu controle",
    "All media" : "Toda mídia",
    "Videos" : "Vídeos",
    "Albums" : "Álbuns",
    "Collaborative albums" : "Álbuns colaborativos",
    "People" : "Pessoas",
    "Folders" : "Pastas",
    "Favorites" : "Favoritos",
    "On this day" : "Nesse dia",
    "Shared with you" : "Compartilhado com você",
    "Tags" : "Etiquetas",
    "Places" : "Lugares",
    "Map" : "Mapa",
    "Photos settings" : "Configurações de fotos",
    "Mark selection as favorite" : "Marcar seleção como favorito",
    "Add selection to favorites" : "Adicionar seleção aos favoritos",
    "Remove selection from favorites" : "Remover seleção dos favoritos",
    "Name of the album" : "Nome do álbum",
    "Location of the album" : "Localização do álbum",
    "Back" : "Voltar",
    "Add collaborators" : "Adicionar colaboradores",
    "Save" : "Salvar",
    "Create album" : "Criar álbum",
    "Add to Album" : "Adicionar ao Álbum",
    "Add selection to album {albumName}" : "Adicionar seleção ao álbum {albumName}",
    "Shared by" : "Compartilhado por",
    "Create a new album." : "Criar um novo álbum.",
    "Create new album" : "Criar novo álbum",
    "New album" : "Novo álbum",
    "_%n item_::_%n photos and videos_" : ["%nitem","%nfotos e vídeos","%nfotos e vídeos"],
    "Add people or groups who can edit your album" : "Adicione pessoas ou grupos que podem editar seu álbum",
    "Search people or groups" : "Pesquisar pessoas ou grupos",
    "No recommendations. Start typing." : "Sem recomendações. Começe a digitar.",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Remova {collaboratorLabel} da lista de colaboradores",
    "Copy the public link" : "Copiar link público",
    "Public link copied!" : "Link público copiado!",
    "Copy public link" : "Copiar link público",
    "Delete the public link" : "Remover link público",
    "Create public link share" : "Criar compartilhamento de link público",
    "Share via public link" : "Compartilhar via link público",
    "Failed to fetch collaborators list." : "Falha ao buscar a lista de colaboradores.",
    "Failed to update album." : "Falha ao atualizar álbum.",
    "This collection does not exist" : "Esta coleção não existe",
    "An error occurred" : "Ocorreu um erro",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%nfoto não identificada","%nfotos não identificadas","%nfotos não identificadas"],
    "Favorite" : "Favorito",
    "Select image {imageName}" : "Selecionar imagem {imageName}",
    "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho normal",
    "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
    "Add to {destination}" : "Adicionar a {destionation}",
    "Go back" : "Voltar",
    "Back to {folder}" : "Voltar para {folder}",
    "Share this folder" : "Compartilhar esta pasta",
    "_{years} year ago_::_{years} years ago_" : ["{anos} ano atrás","{anos} anos atrás","{anos} anos atrás"],
    "Enable squared photos view" : "Ativar exibição de fotos quadradas",
    "Default Photos upload and Albums location" : "Localização padrão de upload para fotos e álbuns",
    "Choose default Photos upload and Albums location" : "Escolha o upload padrão de fotos e o local dos álbuns",
    "Select the default location for your media" : "Selecione o local padrão para sua mídia",
    "Invalid location selected" : "Invalidar localização selecionada",
    "View" : "Exibição",
    "Photos directory" : "Diretório de fotos",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Desmarque todos",
    "Manage collaborators for this album" : "Gerenciar colaboradores para este álbum",
    "Open actions menu" : "Abrir menu de ações",
    "Edit album details" : "Modificar detalhes do álbu",
    "Download all files in album" : "Baixar todos os arquivos do álbum",
    "Delete album" : "Remover álbum",
    "Download selected files" : "Baixar arquivos selecionados",
    "Remove selection from album" : "Remover seleção do álbum",
    "This album does not have any photos or videos yet!" : "Este álbum ainda não possui fotos ou vídeos!",
    "Add photos to this album" : "Adicionar fotos a este álbum",
    "Add photos to {albumName}" : "Add photos to {albumName}",
    "Manage collaborators" : "Gerenciar colaboradores",
    "Save collaborators for this album." : "Salve os colaboradores deste álbum.",
    "Cover photo for album {albumName}" : "Foto da capa do álbum {albumName}",
    "There is no album yet!" : "Ainda não há álbum!",
    "This person could not be found" : "Essa pessoa não pôde ser encontrada",
    "Rename person" : "Renomear pessoa",
    "Merge with different person" : "Unir com outra pessoa",
    "Download selected photos" : "Baixar fotos selecionadas",
    "Remove from favorites" : "Remover dos favoritos",
    "Remove person" : "Remover pessoa",
    "Name of this person" : "Nome desta pessoa",
    "Save." : "Salvar.",
    "Merge person" : "Unir pessoa",
    "Move to different person" : "Ir para uma pessoa diferente",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover fotos para outra pessoa","Mover fotos para outra pessoa","Mover fotos para outra pessoa"],
    "_Remove photo from person_::_Remove photos from person_" : ["Remover fotos desta pessoa","Remover fotos desta pessoa","Remover fotos desta pessoa"],
    "This might take some time depending on the size of your photo library." : "Isso pode levar um tempo a depender do tamanho da sua biblioteca de fotos.",
    "Recognized people will show up here" : "Pessoas reconhecidas aparecerão aqui",
    "This folder does not exist" : "Esta pasta não existe",
    "Loading folders …" : "Carregando pastas…",
    "No photos in here" : "Não há fotos aqui",
    "Taken on {date} at {time}" : "Tirada em {data} às {time}",
    "This place does not have any photos or videos yet!" : "This place does not have any photos or videos yet!",
    "Add photos to this place" : "Adicionar fotos a este espaço",
    "Cover photo for place {placeName}" : "Foto da capa do lespaço {placeName}",
    "There is no place yet!" : "Ainda não há espaço!",
    "Cover photo for shared album {albumName}." : "Foto da capa do álbum compartilhado {albumName}.",
    "Back to tags overview" : "Voltar para a visão geral das etiquetas",
    "No photos with this tag yet" : "Ainda não há fotos com esta etiqueta",
    "No tags yet" : "Ainda não há marcações",
    "Photos with tags will show up here" : "Fotos com marcações serão mostradas aqui",
    "Popular tags" : "Etiquetas populares",
    "Add" : "Adicionar",
    "Add to album" : "Adicionar a álbum",
    "Delete selection" : "Excluir seleção",
    "No photos or videos in here" : "Não há fotos ou vídeos aqui",
    "Unassigned faces" : "Rostos não identificados",
    "_%n photos_::_%n photos_" : ["%nfoto","%nfotos","%nfotos"],
    "Failed to fetch collection." : "Failed to fetch collection.",
    "Failed to fetch collections list." : "Failed to fetch collections list.",
    "Failed to fetch faces list." : "Falha ao buscar lista de rostos.",
    "All your media" : "Todas as suas mídias",
    "Album {title}" : "Álbum {título}",
    "Shared Albums" : "Álbuns Compartilhados",
    "Shared album {title}" : "Álbum compartilhado {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos marcadas",
    "Tagged photo {title}" : "Foto marcada {title}",
    "{title}'s face" : "rosto de {title}",
    "{startDate} to {endDate}" : "{startDate} até {endDate}",
    "Details" : "Detalhes",
    "Failed to rename {oldName} to {faceName}." : "Falha ao renomear {oldName} para {faceName}.",
    "Failed to delete {faceName}." : "Falha ao remover {faceName}.",
    "Failed to delete {fileId}." : "Falha ao excluir {fileId}.",
    "Failed to delete {fileName}." : "Falha ao excluir {fileName}.",
    "Failed to set favorite state for {fileId}." : "Falha ao definir o estado de favorito para {fileId}.",
    "Failed to set favorite state for {fileName}." : "Falha ao definir o estado de favorito para {fileName}.",
    "Go back to the previous view." : "Ir para a visualização anterior.",
    "Go to the add collaborators view." : "Ir para visualização de adicionar colaboradores.",
    "Create the album." : "Criar o álbum.",
    "Back to the new album form." : "Voltar ao formulário de novo álbum.",
    "_Share with %n user_::_Share with %n users_" : ["Compartilhar com %nusuário","Compartilhar com %nusuários","Compartilhar com %nusuários"],
    "Search for collaborators" : "Pesquisar colaboradores",
    "Add {collaboratorLabel} to the collaborators list" : "Adicionar {collaboratorsLabel} à lista de colaboradores",
    "No collaborators available" : "Nenhum colaborador disponível",
    "Failed to fetch album." : "Falha ao buscar álbum.",
    "The file is in the favorites" : "Esse arquivo está nos favoritos",
    "Open the \"{name}\" sub-directory" : "Abrir o subdiretório \"{name}\"",
    "Add photos to the album" : "Adicionar fotos ao álbum",
    "Failed to fetch albums list." : "Falha ao buscar lista de álbuns.",
    "Shared albums" : "Álbuns compartilhados",
    "Create a new album" : "Criar um novo álbum",
    "Add selection to an album" : "Adicionar seleção a um álbu",
    "Failed to create {albumName}." : "Falha ao criar {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Falha ao renomear {currentAlbumName} para {newAlbumName}."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
